@@ -5,21 +5,19 @@ use 5.005;
 use strict;
 use warnings;
 
-use vars qw( $VERSION );
-$VERSION = '0.044_1';
-
-use File::Spec ();
+use vars qw($VERSION);
+$VERSION = '0.03';
 
 sub new {
     my $proto = shift;
     my $class = ref $proto || $proto;
     my $obj = bless {}, $class;
-    return $obj->_init( @_ );
+    return $obj->_init(@_);
 }
 
 # instance variables:
 #   lang - the preferred language of the POD documents
-#   inc - alternate library dirs (if given, replaces the ones in @INC)
+#   base_dir - the base directory where these PODs live
 
 sub _init {
     my $self = shift;
@@ -30,7 +28,7 @@ sub _init {
     #croak "???" unless $args{lang};
     my $lang = uc $args{lang};
     $self->{lang} = $lang;
-    $self->{inc} = $args{inc}; # XXX croak ?! must be array ref
+    $self->{base_dir} = [ _base_dir($lang) ];
 
     return $self;
 }
@@ -45,22 +43,20 @@ sub _extract_lang {
          ;
 }
 
-sub _lib_dirs {
-    my $self = shift;
-    return $self->{inc} ? @{$self->{inc}} : @INC;
+sub _base_dir {
+    my $lang = shift;
+
+    my $dir = $INC{'POD2/Base.pm'};
+    $dir =~ s/Base\.pm\z//;
+    $dir .= $lang . '/';
+    return $dir;
+
 }
 
 sub pod_dirs {
     my $self = shift;
-    my %options = @_ ? %{$_[0]} : ();
-    $options{test} = 1 unless exists $options{test};
+    return @{ $self->{base_dir} };
 
-    my $lang = $self->{lang};
-    my @candidates = map { File::Spec->catdir( $_, 'POD2', $lang ) } $self->_lib_dirs; # XXX the right thing to do
-    if ( $options{test} ) {
-        return grep { -d } @candidates;
-    }
-    return @candidates;
 }
 
 #sub search_perlfunc_re {
@@ -95,3 +91,5 @@ sub print_pod {
 }
 
 1;
+
+
